@@ -8,16 +8,12 @@
 # email      : 2983997560@qq.com
 # Description：自定义数据类型
 """
-import time
-from .dmE import DmE
-from random import uniform
-import win32com.client
+from .dmE import *
 
 
 class CustomE:
     def __init__(self):
-        super(CustomE, self).__init__()
-        self.__dm = DmE()
+        self.dm = tmp
         self.thread = None
         self.hwnd = None
         self.title = None
@@ -27,6 +23,5 @@ class CustomE:
         self.task_list = None
         self.progress = None
 
-    @property
-    def dm(self):
-        return self.__dm
+    def clear(self):
+        pass
